@@ -20,6 +20,8 @@ class LunaProvider(ProviderInterface):
 
 
     def __init__(self):
+        print(self.TERRA_CHAIN_ID)
+        print(self.TERRA_URL)
         self.provider = LCDClient(chain_id = self.TERRA_CHAIN_ID, url = self.TERRA_URL)
 
 
